
Content
=======

.. toctree::
   :maxdepth: 3
   :caption: User Guide

   index
   guide/installation
   guide/the_yaml
   guide/steady_state
   guide/solution
   guide/method.ipynb

.. toctree::
   :maxdepth: 3
   :caption: Tutorials

   tutorial/quickstart
   tutorial/rank.ipynb
   tutorial/hank1.ipynb
   tutorial/hank2.ipynb
